# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [v0.0.7](https://github.com/jackton1/django-model-subscription/releases/tag/v0.0.7) ([compare](https://github.com/jackton1/django-model-subscription/compare/v0.0.6...v0.0.7)) - 2019-11-09

### Fixed
- Fixed missing module. ([04c0483](https://github.com/jackton1/django-model-subscription/commit/04c0483b333633446c49fca2d874fe1ac201abdd)).
- Fixed yaml. ([2350087](https://github.com/jackton1/django-model-subscription/commit/2350087d398964b240581ddff40df7459e6236d5)).

### Misc
- Resolve merge conflicts. ([4f01d6d](https://github.com/jackton1/django-model-subscription/commit/4f01d6dc0e1d90456e310ff38b262394e25355f7)).
- Synced pyproject.toml and updated CHANGELOG.md. ([8bad068](https://github.com/jackton1/django-model-subscription/commit/8bad06889c7d42a8de8059e7ac922a331e481539)).
- Update README.md ([1f7ffb7](https://github.com/jackton1/django-model-subscription/commit/1f7ffb743e4de783e4f68973e12e6cc6b1f5e036)).
- Updated circle ci config. ([d07a29b](https://github.com/jackton1/django-model-subscription/commit/d07a29bb12cae66d25ff56ce4d5921db9f6b2656)).
- Updated circle ci config. ([7eba578](https://github.com/jackton1/django-model-subscription/commit/7eba578b8298454ae9ddc597de32cfc2728e0fff)).
- Updated circle ci config. ([c679d01](https://github.com/jackton1/django-model-subscription/commit/c679d010b66f15ea81bbbfb87758d06e8041a1b5)).
- Updated circle ci config. ([fa3e8b1](https://github.com/jackton1/django-model-subscription/commit/fa3e8b14b60ec92797d1736dc691d73cc19000f5)).
- Updated circle ci config. ([6d270e1](https://github.com/jackton1/django-model-subscription/commit/6d270e148b3819e85ce9a92daf63a0c771970160)).
- Updated circle ci config. ([ac4cba0](https://github.com/jackton1/django-model-subscription/commit/ac4cba0fca343ddde1549a5a82e4928083f7c0f7)).
- Updated the config. ([b7ea22c](https://github.com/jackton1/django-model-subscription/commit/b7ea22cea34e971c7844ddb5d8cd9f990b0f6c9d)).
- Updated the config. ([3cecb41](https://github.com/jackton1/django-model-subscription/commit/3cecb419b36ce5f50b81829ea8a4f38cfa2d6734)).
- Updated the config. ([b32b6ca](https://github.com/jackton1/django-model-subscription/commit/b32b6cae83adaf4444e173b1e05a4c4211c05176)).
- Updated the config. ([1b1e3c2](https://github.com/jackton1/django-model-subscription/commit/1b1e3c29aac08ef833f1020394333dd0858a3656)).
- Updated the config. ([081596b](https://github.com/jackton1/django-model-subscription/commit/081596bc42042e671cffb87a30755f537582da33)).
- Updated the config. ([b29eb8f](https://github.com/jackton1/django-model-subscription/commit/b29eb8f87815bb8d1091d69aa97642f5a890a63d)).
- Updated the config. ([726fc93](https://github.com/jackton1/django-model-subscription/commit/726fc937e8a7833dfc17ef5988bc833d5fe56ac1)).
- Updated the poetry lock file. ([b760875](https://github.com/jackton1/django-model-subscription/commit/b7608757261cab4c4b3864e17c041e19c9c564e9)).
- Updated the README.md ([c16a6b7](https://github.com/jackton1/django-model-subscription/commit/c16a6b71a0003090b2ffbcea77cae22b78677aef)).
- Updated the test template. ([26b6030](https://github.com/jackton1/django-model-subscription/commit/26b60302df27636c66ad347df54b1ba59d04805c)).
- Updated the test. ([69fc7ea](https://github.com/jackton1/django-model-subscription/commit/69fc7ea093a949a021685126f2b7fc91168fbc11)).
- Updated the versions. ([86e15a3](https://github.com/jackton1/django-model-subscription/commit/86e15a3becc63f57174384a0673a1c07da17ae9b)).
- Updated the versions. ([2354e10](https://github.com/jackton1/django-model-subscription/commit/2354e10f32acb57c9dea7df1639303fcba32777e)).
- Updated tox config. ([2fa72d1](https://github.com/jackton1/django-model-subscription/commit/2fa72d192b22c11f7253da3f50234ff5c35e37d3)).
- Updated tox. ([2cf2c8a](https://github.com/jackton1/django-model-subscription/commit/2cf2c8a0e14178de9f74d2115dc1250b17636de6)).
- Updated venv. ([81a80ee](https://github.com/jackton1/django-model-subscription/commit/81a80eedfa1dce40fdac98aa87d34a1b4528e123)).


## [v0.0.6](https://github.com/jackton1/django-model-subscription/releases/tag/v0.0.6) ([compare](https://github.com/jackton1/django-model-subscription/compare/v0.0.5...v0.0.6)) - 2019-11-04

### Added
- Added documentation and improved README.md ([946eac6](https://github.com/jackton1/django-model-subscription/commit/946eac64bd4505fe6bd02da8eef6febb852c9ab4)).
- Added env vars. ([5738df6](https://github.com/jackton1/django-model-subscription/commit/5738df696b061f4c7343e63d2bf4508090d26ef5)).

### Fixed
- Fixed connection errors. ([cc048ad](https://github.com/jackton1/django-model-subscription/commit/cc048ad111f9c53e57612b98027e217f68acb80d)).
- Fixed settings. ([09c26e0](https://github.com/jackton1/django-model-subscription/commit/09c26e02a552163fd03e8749aa08610244f565b5)).
- Fixed test command. ([ccb0d7a](https://github.com/jackton1/django-model-subscription/commit/ccb0d7a7c731755c3c0f9614a63015619befa9a8)).

### Removed
- Removed sdist. ([e2dcdae](https://github.com/jackton1/django-model-subscription/commit/e2dcdaec4a60e3ebdfc76c21ae479900a2e5652d)).

### Misc
- Cleaned up changelog. ([b85e730](https://github.com/jackton1/django-model-subscription/commit/b85e730956cf46ef2dcf1e797a9488c846129bf2)).
- Disable mysql. ([31982c5](https://github.com/jackton1/django-model-subscription/commit/31982c5ff27f3b784d403640d0806a95c970ee06)).
- Excluded venv. ([df9a898](https://github.com/jackton1/django-model-subscription/commit/df9a89826796ed3402ecb3d87935f2368e827bbb)).
- Improved the test. ([5038ba4](https://github.com/jackton1/django-model-subscription/commit/5038ba4daa3c1204e5ecab84acee9f63c0570299)).
- Setup Circle CI and updated the documentation. ([1b32603](https://github.com/jackton1/django-model-subscription/commit/1b326038b077a180a0aa56fb18cd222d7dfe429a)).
- Synced pyproject.toml and updated CHANGELOG.md. ([6ba4a9e](https://github.com/jackton1/django-model-subscription/commit/6ba4a9ec7fb1184b636970476f826070072b3f12)).
- Update README.md ([7901663](https://github.com/jackton1/django-model-subscription/commit/79016634865425b16709cb4c39acf3466d3108b4)).
- Update README.md ([30f8abe](https://github.com/jackton1/django-model-subscription/commit/30f8abea6b4a3d9fe6e2ada2826fc63fa888965b)).
- Update README.md ([b079369](https://github.com/jackton1/django-model-subscription/commit/b079369281a87630e3a3bcfa4e2a30602c5a5052)).
- Update README.md ([4e60e26](https://github.com/jackton1/django-model-subscription/commit/4e60e26c0635f266eb1288754dee0a67e1768b85)).
- Updated circle ci config ([31f3c4b](https://github.com/jackton1/django-model-subscription/commit/31f3c4b3ce96ef1e5ca6e1b1e76f880944d17a9b)).
- Updated circle ci config ([b6d5643](https://github.com/jackton1/django-model-subscription/commit/b6d56434b3fe7fa68c68a31e6b08884ee7e4fe90)).
- Updated circle ci config ([8b41668](https://github.com/jackton1/django-model-subscription/commit/8b4166823554623e4d5a1367e6b2008ad2585020)).
- Updated config. ([5d66309](https://github.com/jackton1/django-model-subscription/commit/5d66309ff6db8181296959b0239837cff2c9717c)).
- Updated deploy. ([94fd3ed](https://github.com/jackton1/django-model-subscription/commit/94fd3edd229339a8d6489d9496fbb199504f8705)).
- Updated license key. ([1d190d4](https://github.com/jackton1/django-model-subscription/commit/1d190d4f38d85a4778e5e5a170b2a85ea42e6b30)).
- Updated settings to fix docs. ([365cef1](https://github.com/jackton1/django-model-subscription/commit/365cef136040a6f39e819362824d3051e5072c10)).
- Updated the dependencies ([3da1ae5](https://github.com/jackton1/django-model-subscription/commit/3da1ae5c75050403c82115e34fe8d68881fc6b93)).
- Updated the docs. ([8fa950c](https://github.com/jackton1/django-model-subscription/commit/8fa950c75490fd1d927cf9f22ceca835716a5754)).
- Updated the docs. ([c7194b5](https://github.com/jackton1/django-model-subscription/commit/c7194b5bfb49dd16ec2c8d97214b0482c6adddde)).
- Updated the docs. ([b87ec7e](https://github.com/jackton1/django-model-subscription/commit/b87ec7e581bce586ad0c0cc25ba997c6e02345b6)).
- Updated the docs. ([3535d8c](https://github.com/jackton1/django-model-subscription/commit/3535d8c69aac9ec49c0cacece0274e718280acaf)).
- Updated the docs. ([9e2ed47](https://github.com/jackton1/django-model-subscription/commit/9e2ed47f79319de1228282211e338c376c2d112f)).
- Updated the package. ([1881961](https://github.com/jackton1/django-model-subscription/commit/1881961d6be48a4dff61395ad4eaa19e072a4f63)).
- Updated the path. ([736f38e](https://github.com/jackton1/django-model-subscription/commit/736f38e4c1b15a0032e8714859dbd0c2f15f158e)).
- Updated the requirements. ([79afc3d](https://github.com/jackton1/django-model-subscription/commit/79afc3da00a3a65106b1a803d96a68261c7b4838)).
- UPdated the settings. ([4e50b93](https://github.com/jackton1/django-model-subscription/commit/4e50b93e667cf2bf65aed10f625cf616ef4c69cf)).
- Updated the test. ([8f3833d](https://github.com/jackton1/django-model-subscription/commit/8f3833d06093d543fabf76f3f17abc3a70653463)).


## [v0.0.5](https://github.com/jackton1/django-model-subscription/releases/tag/v0.0.5) ([compare](https://github.com/jackton1/django-model-subscription/compare/v0.0.4...v0.0.5)) - 2019-10-23

### Fixed
- Fixed bug with ModelSubscription and added new decorators. ([6c616ed](https://github.com/jackton1/django-model-subscription/commit/6c616edb8f27b3287b22289657d8e758d684f815)).

### Misc
- Synced pyproject.toml and updated CHANGELOG.md. ([78ea731](https://github.com/jackton1/django-model-subscription/commit/78ea731d15bf1cff8dbf70d023e90994b2d54bcc)).
- Updated the release to pypi command. ([37cedc0](https://github.com/jackton1/django-model-subscription/commit/37cedc03309dd81ce2d052fa36375387e5db81c5)).


## [v0.0.4](https://github.com/jackton1/django-model-subscription/releases/tag/v0.0.4) ([compare](https://github.com/jackton1/django-model-subscription/compare/v0.0.3...v0.0.4)) - 2019-10-21

### Added
- Added model subscription to sdist. ([df9074e](https://github.com/jackton1/django-model-subscription/commit/df9074e715d894632b1dd97d4b59f7a13a05e622)).

### Removed
- Removed unrelated settings. ([f270a93](https://github.com/jackton1/django-model-subscription/commit/f270a9360beaec4147bf107808a45b720b1c6d34)).

### Misc
- Bumped version and updated the CHANGELOIG.md ([e72e71e](https://github.com/jackton1/django-model-subscription/commit/e72e71e5e6234fc9707fa3281a889a748618e86a)).
- Synced setup.py ([26d7f15](https://github.com/jackton1/django-model-subscription/commit/26d7f151d9dba683d5e81c03e8d173f5581f5177)).
- Updated pyproject.toml ([98a5fc7](https://github.com/jackton1/django-model-subscription/commit/98a5fc7187c94e0db73c2ec1b7e640d1ffaae2b2)).


## [v0.0.3](https://github.com/jackton1/django-model-subscription/releases/tag/v0.0.3) ([compare](https://github.com/jackton1/django-model-subscription/compare/v0.0.1...v0.0.3)) - 2019-10-21

### Removed
- Removed .bumpversion.cfg ([2140477](https://github.com/jackton1/django-model-subscription/commit/2140477779916f3c7f1abc003116c6371a6ff8d0)).

### Misc
- Create LICENSE ([ad04007](https://github.com/jackton1/django-model-subscription/commit/ad04007be8a1790d840444a0c25dbbee88deb060)).
- Updated project files. ([4193906](https://github.com/jackton1/django-model-subscription/commit/4193906f069a3ae7e3c175008bf9a16978d74ca0)).
- Updated the deploy command. ([06ae3f7](https://github.com/jackton1/django-model-subscription/commit/06ae3f7756201f983fb12794ab992f6b2474bacd)).
- Updated version 0.0.1 -> 0.0.2. ([85ab174](https://github.com/jackton1/django-model-subscription/commit/85ab174da88babbdde6b132e4c2baa7c95dcd40a)).


## [v0.0.1](https://github.com/jackton1/django-model-subscription/releases/tag/v0.0.1) ([compare](https://github.com/jackton1/django-model-subscription/compare/fadbc19ce2b1307403e85a707d085e865bcfe453...v0.0.1)) - 2019-10-20

### Added
- Added subscription and observers module. ([4405e25](https://github.com/jackton1/django-model-subscription/commit/4405e25da8b90d77aa0c4fe306836d5c4b7f7e41)).

### Misc
- Initial project setup. ([fadbc19](https://github.com/jackton1/django-model-subscription/commit/fadbc19ce2b1307403e85a707d085e865bcfe453)).


